Skip site navigation (1)Skip section navigation (2)
Date:      Tue, 19 Jun 2012 22:23:59 +0000 (UTC)
From:      Pawel Jakub Dawidek <pjd@FreeBSD.org>
To:        src-committers@freebsd.org, svn-src-all@freebsd.org, svn-src-head@freebsd.org
Subject:   svn commit: r237277 - head/sys/kern
Message-ID:  <201206192223.q5JMNxs3000863@svn.freebsd.org>

next in thread | raw e-mail | index | archive | help
Author: pjd
Date: Tue Jun 19 22:23:59 2012
New Revision: 237277
URL: http://svn.freebsd.org/changeset/base/237277

Log:
  Check proper flag (PDF_DAEMON, not PD_DAEMON) when deciding if the process
  should be killed or not.
  
  This fixes killing pdfork(2)ed process on last close of the corresponding
  process descriptor.
  
  Reviewed by:	rwatson
  MFC after:	1 month

Modified:
  head/sys/kern/sys_procdesc.c

Modified: head/sys/kern/sys_procdesc.c
==============================================================================
--- head/sys/kern/sys_procdesc.c	Tue Jun 19 22:21:59 2012	(r237276)
+++ head/sys/kern/sys_procdesc.c	Tue Jun 19 22:23:59 2012	(r237277)
@@ -338,7 +338,7 @@ procdesc_reap(struct proc *p)
 
 /*
  * procdesc_close() - last close on a process descriptor.  If the process is
  * still running, terminate with SIGKILL (unless PD_DAEMON is set) and let
  * init(8) clean up the mess; if not, we have to clean up the zombie ourselves.
  */
 static int
@@ -386,7 +386,7 @@ procdesc_close(struct file *fp, struct t
 		 */
 		p->p_sigparent = SIGCHLD;
 		proc_reparent(p, initproc);
-		if ((pd->pd_flags & PD_DAEMON) == 0)
+		if ((pd->pd_flags & PDF_DAEMON) == 0)
 			kern_psignal(p, SIGKILL);
 		PROC_UNLOCK(p);
 		sx_xunlock(&proctree_lock);
@@ -338,7 +338,7 @@ procdesc_reap(struct proc *p)
 /*
  * procdesc_close() - last close on a process descriptor.  If the process is
- * still running, terminate with SIGKILL (unless PD_DAEMON is set) and let
+ * still running, terminate with SIGKILL (unless PDF_DAEMON is set) and let
  * init(8) clean up the mess; if not, we have to clean up the zombie ourselves.
  */



Want to link to this message? Use this URL: <https://mail-archive.FreeBSD.org/cgi/mid.cgi?201206192223.q5JMNxs3000863>